@@ -583,7 +583,7 @@ def must_complete_times(
         elif which == 'end':
             dt_suss, _next_fact = find_next_datetime(later_facts)
             if dt_suss is None:
-                dt_suss = controller.store.now
+                dt_suss = controller.now
         return dt_suss
 
     def conflicts_add_unresolved_relative(fact, which, conflicts, dt_fact):
@@ -1054,6 +1054,7 @@ def resolve_overlapping(fact, conflicts, squash_sep='', allow_momentaneous=False
 
 # ***
 
+# (lb): This fcn. could be moved to dob or dob-bright; only dob uses it.
 def mend_fact_timey_wimey(controller, fact, time_hint, other_edits={}):
     """"""
     def _mend_fact_timey_wimey():
