@@ -44,6 +44,9 @@ class ActionManager(object):
         )
         self.setup_key_bindings()
 
+    def finalize_standup(self):
+        self.key_bonder.print_warnings()
+
     # ***
 
     def _wire_keys(self, key_bindings):
@@ -117,14 +120,12 @@ class ActionManager(object):
         self.setup_key_bindings_modal()
         self.setup_key_bindings_commando()
         self.setup_key_bindings_delta_time()
-        self.key_bonder.print_warnings()
 
     def setup_key_bindings_shared(self):
         bindings = []
         bindings += self.key_bonder.save_and_quit(self.key_action_map)
         bindings += self.key_bonder.widget_focus(self.key_action_map)
         bindings += self.key_bonder.begin_commando(self.key_action_map)
-        bindings += self.key_bonder.begin_delta_time(self.key_action_map)
 
         self.key_bindings_shared = bindings
 
@@ -133,7 +134,8 @@ class ActionManager(object):
         bindings += self.key_bonder.normal(self.key_action_map)
         bindings += self.key_bonder.edit_fact(self.key_action_map)
         bindings += self.key_bonder.nudge_time(self.key_action_map)
-        bindings += self.key_bonder.count_modifier(self.key_action_map)
+        bindings += self.key_bonder.begin_delta_time(self.key_action_map)
+        bindings += self.key_bonder.command_modifier(self.key_action_map)
         bindings += self.key_bonder.create_delete_fact(self.key_action_map)
         bindings += self.key_bonder.clipboard(self.key_action_map)
         bindings += self.key_bonder.undo_redo(self.key_action_map, 'content')
