@@ -381,6 +381,8 @@ class EditsManager(object):
         def at_least_load_latest_fact():
             self.controller.affirm(len(self.conjoined.groups) == 0)
             latest_fact = self.controller.facts.antecedent(
+                # Should not matter controller.store.now_tz_aware() vs. now
+                # because this runs just once, on carousel.gallop startup.
                 ref_time=self.controller.now,
             )
             self.controller.affirm(latest_fact is not None)
@@ -543,6 +545,16 @@ class EditsManager(object):
 
     # ***
 
+    def jump_fact_first(self):
+        """"""
+        self.conjoined.jump_fact_first()
+
+    def jump_fact_final(self):
+        """"""
+        self.conjoined.jump_fact_final()
+
+    # ***
+
     def save_edited_facts(self):
         """"""
         # 2019-01-23 22:28: (lb): I wrote this quick in the past hour.
