@@ -36,7 +36,7 @@ class UpdateHandler(object):
     def __init__(self, carousel):
         self.carousel = carousel
         self.long_press_multiplier_init()
-        self.count_modifier_init()
+        self.command_modifier_init()
 
     def long_press_multiplier_init(self):
         self.last_time_time_adjust = None
@@ -46,6 +46,25 @@ class UpdateHandler(object):
     def standup(self):
         self.edits_manager = self.carousel.edits_manager
         self.zone_manager = self.carousel.zone_manager
+        self.load_date_separators()
+
+    def load_date_separators(self):
+        # For convenience later.
+        self.re_date_seps = None
+        # (lb): Highly coupled now. I know. Oh well.
+        date_seps = self.carousel.action_manager.key_bonder.date_separators
+        if not date_seps:
+            return
+        # Unpack array of arrays.
+        sep_choices = '|'.join([''.join(sep_arr) for sep_arr in date_seps])
+        self.re_date_seps = re.compile(r'^({})$'.format(sep_choices))
+
+    # ***
+
+    def persist_status(self, hot_notif):
+        self.zone_manager.zone_lowdown.update_status(
+            hot_notif, clear_after_secs=0,
+        )
 
     # ***
 
@@ -290,7 +309,7 @@ class UpdateHandler(object):
         self.edit_time_adjust(5, 'end')
 
     def edit_time_adjust(self, delta_mins, start_or_end, end_maybe=None):
-        modifier = self.count_modifier_parse()
+        modifier = self.command_modifier_parse()
         if modifier is not None:
             delta_mins *= modifier
         delta_time = self.edit_time_multiplier(delta_mins)
@@ -299,11 +318,12 @@ class UpdateHandler(object):
             start_or_end,
             end_maybe,
             gap_okay=self.time_gap_allowed,
+            modified=modifier is not None,
         )
         self.edit_time_reset_refresh()
 
     def edit_time_reset_refresh(self):
-        self.count_modifier_reset()
+        self.command_modifier_reset()
         self.zone_manager.reset_diff_fact()
         self.zone_manager.selectively_refresh()
 
@@ -321,7 +341,7 @@ class UpdateHandler(object):
     # press. But I added reset_time_multipliers decorator to key_action_map
     # handlers, so we probably do not even need this threshold, because now
     # if last_time_time_adjust is set, it should mean user has not pressed
-    # any other key since (see also count_modifier_any_key).
+    # any other key since (see also command_modifier_any_key).
     DOUBLE_KEYLICK_THRESHOLD = 0.33
     MULTIPLY_BY_05_THRESHOLD = 4
     MULTIPLY_BY_10_THRESHOLD = 7
@@ -422,31 +442,43 @@ class UpdateHandler(object):
         """"""
         self.began_commando = self._key_sequence_str(event)
         self.typed_commando = ''
-        self.zone_manager.zone_lowdown.update_status(
-            self.began_commando,
-            clear_after_secs=0,
-        )
+        self.persist_status(self.began_commando)
         self.carousel.action_manager.wire_keys_commando()
 
+    @catch_action_exception
+    def cancel_commando(self, event=None):
+        self.zone_manager.zone_lowdown.reset_status()
+        self.reset_commando()
+
     @catch_action_exception
     def parts_commando(self, event):
         """"""
-        self.typed_commando += self._key_sequence_str(event)
-        self.zone_manager.zone_lowdown.update_status(
-            self.began_commando + self.typed_commando,
-            clear_after_secs=0,
-        )
+        # Don't use key_sequence but go straight for the raw data.
+        self.typed_commando += event.data
+        self.persist_status(self.began_commando + self.typed_commando)
+
+    @catch_action_exception
+    def backspace_commando(self, event):
+        if not self.typed_commando:
+            self.cancel_commando()
+        else:
+            self.typed_commando = self.typed_commando[:-1]
+            self.persist_status(self.began_commando + self.typed_commando)
 
     @catch_action_exception
     def final_commando(self, event):
         """"""
+        # Reset the status message first, because the command being called
+        # may have something to say.
+        self.zone_manager.zone_lowdown.reset_status()
         hot_notif = self.colon_commando(event, self.typed_commando)
-        del self.began_commando
-        del self.typed_commando
         if hot_notif:
             self.zone_manager.zone_lowdown.update_status(hot_notif)
-        else:
-            self.zone_manager.zone_lowdown.reset_status()
+        self.reset_commando()
+
+    def reset_commando(self):
+        del self.began_commando
+        del self.typed_commando
         self.carousel.action_manager.unwire_keys_commando()
 
     # ***
@@ -462,7 +494,21 @@ class UpdateHandler(object):
             # E.g., `:q`.
             self.carousel.exit_command(event)
         elif typed_commando == keys_config['save_quit_commando']:
-            self.carousel.save_edited_and_exit(event)
+            # (lb): My first go was to just save-and-exit, but then I thought
+            # maybe we could linger for a hot mo. to let user see the 'Saved'
+            # message. I'll keep both options here for now: maybe later we'll
+            # want to make (yet another) user configurable option.
+            save_exit_message_linger = 0.999  # Herman Cain would be proud.
+            if save_exit_message_linger <= 0:
+                self.carousel.save_edited_and_exit(event)
+            else:
+                self.carousel.save_edited_and_live(event)
+                # Hang out briefly to provide 'save' command feedback (via
+                # 'Saved {} Facts' status message). (lb): This seems like a
+                # good thing for new users; veteran dobbers will probably
+                # disable (by setting configurable option to '0' seconds).
+                time.sleep(save_exit_message_linger)
+                self.carousel.exit_command(event)
         else:
             # (lb): Copying Vim's message for now. Verbatim. Don't judge.
             msg = 'E492: Not an editor command: {}'.format(typed_commando)
@@ -470,92 +516,144 @@ class UpdateHandler(object):
 
     # ***
 
-    def count_modifier_init(self):
-        self.count_modifier = None
+    def command_modifier_init(self):
+        self.command_modifier = None
         self.final_modifier = None
         self.time_gap_allowed = None
+        self.time_gap_keycode = ''
         self.delta_time_target = None
+        self.delta_time_keycode = ''
 
-    def count_modifier_setup(self):
-        self.count_modifier = ''
+    def command_modifier_setup(self, keep_gap=False):
+        self.command_modifier = ''
         self.final_modifier = None
-        self.time_gap_allowed = False
+        if not keep_gap:
+            self.time_gap_allowed = False
         # If user presses '+'/'-', then we'll set self.delta_time_target.
 
     # ***
 
     @catch_action_exception
-    def count_modifier_any_key(self, event=None):
+    def command_modifier_any_key(self, event=None):
         # Note: This only catches keys not mapped elsewhere.
         # And we only care about digits and decimal points.
-        if self.count_modifier is None:
+        if self.command_modifier is None:
             # Do not reset count modifier whilst building it!
-            self.count_modifier_setup()
-        self.count_modifier_feed(event)
+            self.command_modifier_setup()
+        self.command_modifier_feed(event)
+        self.command_modifier_stat()
+
+    @catch_action_exception
+    def backspace_command_modifier(self, event, limit=1):
+        if self.command_modifier is None:
+            return
+        if len(self.command_modifier) <= limit:
+            # Not quite the right name because not necessarily in delta-time
+            # mode, but the effect is what we want.
+            self.cancel_delta_time()
+        else:
+            self.command_modifier = self.command_modifier[:-1]
+            self.command_modifier_stat()
+
+    def command_modifier_stat(self):
+        statmsg = ''
+        statmsg += self.delta_time_keycode
+        statmsg += self.command_modifier if self.command_modifier else ''
+        statmsg += self.time_gap_keycode if self.time_gap_allowed else ''
+        self.persist_status(statmsg)
 
     # ***
 
     @catch_action_exception
     def begin_delta_time_start(self, event):
         """"""
-        self.carousel.action_manager.wire_keys_delta_time()
-        if self.count_modifier is None:
-            # This allows user to press '!' before '+'.
-            self.count_modifier_setup()
         self.delta_time_target = 'end'
+        self.begin_delta_time_both(event)
 
     @catch_action_exception
     def begin_delta_time_end(self, event):
         """"""
-        self.carousel.action_manager.wire_keys_delta_time()
-        if self.count_modifier is None:
-            # This allows user to press '!' before '-'.
-            self.count_modifier_setup()
         self.delta_time_target = 'start'
+        self.begin_delta_time_both(event)
+
+    def begin_delta_time_both(self, event):
+        self.carousel.action_manager.wire_keys_delta_time()
+        # Allow user to press '!' before '+'/'-'. But not '!' then some
+        # numbers, then '+'/'-', "that would be illegal". (So, e.g.,
+        # if user pressed `!123+`, we'd ignore the `!123`.
+        self.command_modifier_setup(keep_gap=not self.command_modifier)
+        self.delta_time_keycode = self._key_sequence_str(event)
+        self.command_modifier_stat()
+
+    @catch_action_exception
+    def cancel_delta_time(self, event):
+        self.zone_manager.zone_lowdown.reset_status()
+        self.command_modifier_reset()
 
     RE_NUMERIC = re.compile('^[0-9]$')
 
     @catch_action_exception
     def parts_delta_time(self, event):
         """"""
-        self.count_modifier_feed(event)
+        self.command_modifier_feed(event)
+        self.command_modifier_stat()
 
-    def count_modifier_feed(self, event):
+    def command_modifier_feed(self, event):
+        """Accumulates individual key presses until a command action is specified.
+
+        This is like the [count] prefix option in Vim, but we also support
+        entering a date instead, for the `G` command (whereas in Vim, `nG`
+        moves the cursor to line 'n', in Dob, `nG` moves the current view
+        to date 'n').
+        """
         # If user pressed allow-gap key already (e.g., '!'), do not allow
         # more time to be entered; be strict and reset instead. Unless
         # user has not entered any time yet.
         if self.final_modifier:
-            self.count_modifier_reset()
+            self.command_modifier_reset()
         # We could allow any character and then parse at error, potentially
         # showing an error message. Or, if user types non-number now, we
         # could just go back to old state. -- It's not completely silent,
         # as the cursor will reappear.
         elif event.data == '.':
-            if '.' in self.count_modifier:
+            if '.' in self.command_modifier:
                 # So strict!
-                self.count_modifier_reset()
+                self.command_modifier_reset()
             else:
-                self.count_modifier += '.'
-        elif UpdateHandler.RE_NUMERIC.match(event.data):
-            self.count_modifier += event.data
+                self.command_modifier += '.'
+        elif (
+            UpdateHandler.RE_NUMERIC.match(event.data)
+            or self.re_date_seps.match(event.data)
+        ):
+            self.command_modifier += event.data
         else:
-            # Not '[0-9]' or '.'. Ignore it and reset state.
-            self.count_modifier_reset()
+            # Not a number ('[0-9]'), a dot ('.'), or a date separator
+            # ('-', etc.). Ignore it and reset state.
+            self.command_modifier_reset()
+
+    @catch_action_exception
+    def backspace_delta_time(self, event):
+        self.backspace_command_modifier(event, limit=0)
 
     @catch_action_exception
     def allow_time_gap(self, event):
         """"""
-        if self.time_gap_allowed is True:
-            # Be strict. Consider a second '!' to be syntax error, so reset.
-            self.count_modifier_reset()
+        self.time_gap_keycode = self._key_sequence_str(event)
+        if self.time_gap_allowed is not None:
+            # (lb): Originally, I considered a second '!' to be a syntax error,
+            # and would reset here -- command_modifier_reset() -- but there's
+            # no reason we cannot toggle, especially because status message
+            # shows current command modifier input.
+            self.time_gap_allowed = not self.time_gap_allowed
         else:
-            if self.count_modifier is None:
+            if self.command_modifier is None:
                 # Allow '!' to precede '[0-9]' or '+'/'-'.
-                self.count_modifier_setup()
-            elif self.count_modifier:
+                self.command_modifier_setup()
+            elif self.command_modifier:
                 # User entered some numbers or a decimal already. Mark it final
-                self.final_modifier = self.count_modifier
+                self.final_modifier = self.command_modifier
             self.time_gap_allowed = True
+        self.command_modifier_stat()
 
     @catch_action_exception
     def final_delta_time_apply(self, event):
@@ -573,7 +671,7 @@ class UpdateHandler(object):
         self.apply_delta_time(event, scalar=60)
 
     def apply_delta_time(self, event, scalar):
-        delta_time = self.count_modifier_parse()
+        delta_time = self.command_modifier_parse()
         if delta_time is None:
             # Happens if user types, e.g., `+h`, i.e., without any digits.
             self.edit_time_reset_refresh()
@@ -590,20 +688,21 @@ class UpdateHandler(object):
             apply_time,
             self.delta_time_target,
             gap_okay=self.time_gap_allowed,
+            modified=True,
         )
         self.edit_time_reset_refresh()
 
-    def count_modifier_parse(self):
-        if not self.count_modifier:
+    def command_modifier_parse(self):
+        if not self.command_modifier:
             return None
         try:
-            delta_time = int(self.count_modifier)
+            delta_time = int(self.command_modifier)
         except ValueError:
-            delta_time = float(self.count_modifier)
+            delta_time = float(self.command_modifier)
         return delta_time
 
     def apply_count_multiplier(self, count=1, floats=False):
-        modifier = self.count_modifier_parse()
+        modifier = self.command_modifier_parse()
         if modifier is not None:
             count = count * modifier
             if not floats:
@@ -611,25 +710,23 @@ class UpdateHandler(object):
         self.reset_time_multipliers()
         return count
 
-    @catch_action_exception
-    def panic_delta_time(self, event):
-        """"""
-        self.count_modifier_reset()
-
     def reset_time_multipliers(self):
-        self.count_modifier_reset()
+        self.command_modifier_reset()
         # Also the long-press multipliers.
         self.last_time_time_adjust = None
         self.init_time_time_adjust = None
         self.press_cnt_time_adjust = 0
 
-    def count_modifier_reset(self):
-        if self.count_modifier is None:
+    def command_modifier_reset(self):
+        if self.command_modifier is None:
             return
-        self.count_modifier = None
+        self.command_modifier = None
         self.final_modifier = None
         self.time_gap_allowed = None
+        self.time_gap_keycode = ''
         if self.delta_time_target is not None:
             self.carousel.action_manager.unwire_keys_delta_time()
             self.delta_time_target = None
+            self.delta_time_keycode = ''
+        self.zone_manager.zone_lowdown.reset_status()
 
